@@ -12,4 +12,4 @@ GROUP_PARAMS = {
     }
 }
 
-register(GROUP_PARAMS, Group)
\ No newline at end of file
+register(GROUP_PARAMS, Group, 'object_permissions')
\ No newline at end of file
